<?php
	/**
	* Setup
	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
	* @package phpgwapi
	* @subpackage setup
	* @version $Id: default_records.inc.php 4175 2009-11-22 14:00:45Z sigurd $
	*/

	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('aa','Afar','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ab','Abkhazian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('af','Afrikaans','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('am','Amharic','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ar','Arabic','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('as','Assamese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ay','Aymara','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('az','Azerbaijani','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ba','Bashkir','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('be','Byelorussian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('bg','Bulgarian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('bh','Bihari','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('bi','Bislama','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('bn','Bengali','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('bo','Tibetan','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('br','Breton','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ca','Catalan','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('co','Corsican','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('cs','Czech','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('cy','Welsh','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('da','Danish','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('de','German','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('dz','Bhutani','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('el','Greek','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('en','English','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('eo','Esperanto','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('es','Spanish','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('et','Estonian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('eu','Basque','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('fa','Persian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('fi','Finnish','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('fj','Fiji','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('fo','Faeroese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('fr','French','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('fy','Frisian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ga','Irish','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('gd','Scots Gaelic','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('gl','Galician','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('gn','Guarani','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('gu','Gujarati','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ha','Hausa','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('he','Hebrew','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('hi','Hindi','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('hr','Croatian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('hu','Hungarian','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('hy','Armenian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ia','Interlingua','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ie','Interlingue','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ik','Inupiak','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('id','Indonesian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('is','Icelandic','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('it','Italian','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('iu', 'Inuktitut', 'No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ja','Japanese','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('jw','Javanese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ka','Georgian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('kk','Kazakh','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('kl','Greenlandic','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('km','Cambodian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('kn','Kannada','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ko','Korean','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ks','Kashmiri','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ku','Kurdish','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ky','Kirghiz','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('la','Latin','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ln','Lingala','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('lo','Laothian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('lt','Lithuanian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('lv','Latvian / Lettish','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mg','Malagasy','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mi','Maori','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mk','Macedonian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ml','Malayalam','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mn','Mongolian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mo','Moldavian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mr','Marathi','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ms','Malay','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('mt','Maltese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('my','Burmese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('na','Nauru','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ne','Nepali','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('nl','Dutch','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('no','Norwegian','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('oc','Occitan','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('om','Oromo / Afan','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('or','Oriya','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('pa','Punjabi','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('pl','Polish','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ps','Pashto / Pushto','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('pt','Portuguese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('qu','Quechua','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('rm','Rhaeto-Romance','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('rn','Kirundi','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ro','Romanian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ru','Russian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('rw','Kinyarwanda','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sa','Sanskrit','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sd','Sindhi','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sg','Sangro','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sh','Serbo-Croatian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('si','Singhalese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sk','Slovak','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sl','Slovenian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sm','Samoan','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sn','Shona','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('so','Somali','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sq','Albanian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sr','Serbian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ss','Siswati','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('st','Sesotho','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('su','Sudanese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sv','Swedish','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('sw','Swahili','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ta','Tamil','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('te','Tegulu','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tg','Tajik','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('th','Thai','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ti','Tigrinya','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tk','Turkmen','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tl','Tagalog','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tn','Setswana','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('to','Tonga','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tr','Turkish','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ts','Tsonga','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tt','Tatar','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('tw','Twi','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ug', 'Uigur', 'No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('uk','Ukrainian','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('ur','Urdu','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('uz','Uzbek','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('vi','Vietnamese','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('vo','Volapuk','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('wo','Wolof','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('xh','Xhosa','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('yi','Yiddish','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('yo','Yoruba','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('zh','Chinese (Simplified)','No')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('zt','Chinese (Traditional)','Yes')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('zu','Zulu','No')");

	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_interserv(server_name,server_host,server_url,trust_level,trust_rel,server_mode) VALUES ('phpGW cvsdemo',NULL,'http://www.phpgroupware.org/cvsdemo/xmlrpc.php',99,0,'xmlrpc')");

	$GLOBALS['phpgw_setup']->oProc->query ("INSERT INTO phpgw_vfs (owner_id, createdby_id, modifiedby_id, created, modified, size, mime_type, deleteable, comment, app, directory, name, link_directory, link_name) VALUES (0,0,0,'1970-01-01',NULL,NULL,'Directory','Y',NULL,NULL,'/','', NULL, NULL)");
	$GLOBALS['phpgw_setup']->oProc->query ("INSERT INTO phpgw_vfs (owner_id, createdby_id, modifiedby_id, created, modified, size, mime_type, deleteable, comment, app, directory, name, link_directory, link_name) VALUES (0,0,0,'1970-01-01',NULL,NULL,'Directory','Y',NULL,NULL,'/','home', NULL, NULL)");
	

	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_types (contact_type_descr,contact_type_table) VALUES ('Persons','phpgw_contact_person')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_types (contact_type_descr,contact_type_table) VALUES ('Organizations','phpgw_contact_org')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('email')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('phone')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('mobile phone')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('fax')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('instant messaging')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('url')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_type (type) VALUES ('other')");
	// Address type
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_addr_type (description) VALUES ('work')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_addr_type (description) VALUES ('home')");
	// Note type
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_note_type (description) VALUES ('general')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_note_type (description) VALUES ('vcard')");
	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_note_type (description) VALUES ('system')");

	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='email'");
	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
	for($i = 0; $i < count($comm_type_ids); $i++)
	{
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id']
			. ",'home email'" 
			.  ")");

		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'work email'" 
			.  ")");
	}

	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='phone'"); 
	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
	for($i = 0; $i < count($comm_type_ids); $i++)
	{
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'home phone'"
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'work phone'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'voice phone'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'msg phone'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES ("
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'pager'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'bbs'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'modem'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'isdn'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'video'" 
			.  ")");
	}
	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='fax'"); 
	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
	for($i = 0; $i < count($comm_type_ids); $i++)
	{
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'home fax'"
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'work fax'" 
			.  ")");
	}
	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='mobile phone'"); 
	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
	for($i = 0; $i < count($comm_type_ids); $i++)
	{
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'mobile (cell) phone'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'car phone'" 
			.  ")");
	}
	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='instant messaging'"); 
	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
	for($i = 0; $i < count($comm_type_ids); $i++)
	{
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'msn'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'aim'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'yahoo'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'icq'" 
			.  ")");
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES ("
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'jabber'" 
			.  ")");				
	}
	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='url'"); 
	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
	for($i = 0; $i < count($comm_type_ids); $i++)
	{
		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
			. $comm_type_ids[$i]['comm_type_id'] 
			. ",'website'" 
			.  ")");
	}

	// Sane defaults for the API
	$values = array
	(
		'max_access_log_age'	=> 90,
		'block_time'			=> 30,
		'num_unsuccessful_id'	=> 3,
		'num_unsuccessful_ip'	=> 3,
		'install_id'			=> sha1(uniqid(rand(), true)),
		'max_history'			=> 20,
		'sessions_checkip'		=> 'True',
		'sessions_timeout'		=> 1440,
		'addressmaster'			=> -3,
		'log_levels'			=> serialize(array('global_level' => 'E', 'module' => array(), 'user' => array())),
		'freshinstall'			=> 1,
		'usecookies'			=> 'True'
	);

	foreach ( $values as $name => $val )
	{
		$sql = "INSERT INTO phpgw_config VALUES('phpgwapi', '{$name}', '{$val}')";
		$GLOBALS['phpgw_setup']->oProc->query($sql, __LINE__, __FILE__);
	}

	$GLOBALS['phpgw']->locations->add('changepassword', 'allow user to change password', 'preferences', false);
	$GLOBALS['phpgw']->locations->add('anonymous', 'allow anonymous sessions for public modules', 'phpgwapi', false);
